@@ -2,7 +2,7 @@
 
 """Py2SQL.py2sql: provides entry point main()."""
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 import os
 import sqlite3
@@ -11,7 +11,7 @@ from typing import *
 
 import Py2SQL.util_for_db as util
 import Py2SQL.util_for_handle_usual_data as handler
-from config import *
+from .config import *
 from Py2SQL import sql_queries
 
 
